@@ -1,5 +1,9 @@
+"""The official Amplitude Python SDK"""
+
+
 from amplitude.client import Amplitude
-from amplitude.event import BaseEvent, EventOptions, Identify, Revenue, IdentifyEvent, GroupIdentifyEvent, RevenueEvent
+from amplitude.event import BaseEvent, EventOptions, Identify, Revenue, IdentifyEvent, \
+    GroupIdentifyEvent, RevenueEvent, Plan
 from amplitude.config import Config
 from amplitude.constants import PluginType
 from amplitude.plugin import EventPlugin, DestinationPlugin
